@@ -24,6 +24,7 @@
 #include <libgnomeui/gnome-url.h>
 #include <gdk/gdkx.h>
 
+#include <libpanel-util/panel-glib.h>
 #include <libpanel-util/panel-keyfile.h>
 
 #include "launcher.h"
@@ -445,7 +446,7 @@ drag_drop_cb (GtkWidget	        *widget,
 	if ( ! is_this_drop_ok (widget, context))
 		return FALSE;
 
-	if (text_uri_list == 0)
+	if (text_uri_list == NULL)
 		text_uri_list = gdk_atom_intern_static_string ("text/uri-list");
 
 	gtk_drag_get_data (widget, context, text_uri_list, time);
@@ -618,10 +619,12 @@ setup_button (Launcher *launcher)
 						    "Comment");
 
 	/* Setup tooltip */
-	if ( ! string_empty (comment))
+	if (!PANEL_GLIB_STR_EMPTY (name) && !PANEL_GLIB_STR_EMPTY (comment))
 		str = g_strdup_printf ("%s\n%s", name, comment);
-	else
+	else if (!PANEL_GLIB_STR_EMPTY (name))
 		str = g_strdup (name);
+	else
+		str = g_strdup (comment);
 
 	g_free (name);
 	g_free (comment);
