@@ -8,9 +8,6 @@ G_BEGIN_DECLS
 
 typedef void (*UpdateFunction) (gpointer);
 
-/* TRUE if string is NULL or the first character is '\0' */
-#define		string_empty(s)		((s)==NULL||((char *)(s))[0]=='\0')
-
 #define		sure_string(s)		((const char *)((s)!=NULL?(s):""))
 
 void            panel_util_launch_from_key_file (GKeyFile                *keyfile,
@@ -94,37 +91,6 @@ GdkPixbuf *panel_util_cairo_rgbdata_to_pixbuf (unsigned char *data,
 					       int            width,
 					       int            height);
 
-GKeyFile *panel_util_key_file_new_desktop  (void);
-gboolean  panel_util_key_file_to_file      (GKeyFile       *keyfile,
-					    const gchar    *file,
-					    GError        **error);
-gboolean panel_util_key_file_load_from_uri (GKeyFile       *keyfile,
-					    const gchar    *uri,
-					    GKeyFileFlags   flags,
-					    GError        **error);
-gboolean panel_util_key_file_get_boolean   (GKeyFile       *keyfile,
-					    const gchar    *key,
-					    gboolean        default_value);
-#define panel_util_key_file_get_string(key_file, key) \
-	 g_key_file_get_string (key_file, "Desktop Entry", key, NULL)
-#define panel_util_key_file_get_locale_string(key_file, key) \
-	 g_key_file_get_locale_string(key_file, "Desktop Entry", key, NULL, NULL)
-#define panel_util_key_file_set_boolean(key_file, key, value) \
-	 g_key_file_set_boolean (key_file, "Desktop Entry", key, value)
-#define panel_util_key_file_set_string(key_file, key, value) \
-	 g_key_file_set_string (key_file, "Desktop Entry", key, value)
-void    panel_util_key_file_set_locale_string (GKeyFile    *keyfile,
-					       const gchar *key,
-					       const gchar *value);
-#define panel_util_key_file_remove_key(key_file, key) \
-	g_key_file_remove_key (key_file, "Desktop Entry", key, NULL)
-void panel_util_key_file_remove_locale_key (GKeyFile    *keyfile,
-					    const gchar *key);
-void panel_util_key_file_remove_all_locale_key (GKeyFile    *keyfile,
-						const gchar *key);
-void panel_util_key_file_ensure_C_key (GKeyFile   *keyfile,
-				       const char *key);
-
 char *guess_icon_from_exec (GtkIconTheme *icon_theme,
 			    GKeyFile     *key_file);
 
